/* 
    kwintv using Bt848 frame grabber driver

    Copyright (C) 1998 Moritz Wenk (wenk@mathematik.uni-kl.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef wintvmainincluded
#define wintvmainincluded

#include <wintv.h>

#include <qpixmap.h>
//#include <qlcdnum.h>
#include <qpushbt.h>

#include <ctab.h>
#include <cselector.h>
#include <coptions.h>
#include <cfreq.h>

#include <otab.h>
#include <omixdev.h>
#include <ogeneral.h>
#include <osnapshot.h>
#include <oaspectratio.h>
#include <ofullscreen.h>

#include <kapp.h>
#include <kbutton.h>
#include <ktoolbar.h>
#include <ktopwidget.h>
#include <kkeyconf.h> 
#include <kstatusbar.h>

//#include <wintvtoolbar.h>
#include <wintvscreen.h>
#include <rcfile.h>
#include <channel.h>
#include <wintvcsan.h>
#include <mixer.h>
#include <videoclip.h>
#include <kirc.h>

#ifdef myDEBUG
#define mainDEBUG
#endif

#define FRAME_NONE 0
#define FRAME_LEFT 1
#define FRAME_RIGHT 2
#define FRAME_UP 3
#define FRAME_DOWN 4

#define UPPER_LEFT  1
#define LOWER_LEFT  2
#define UPPER_RIGHT 3
#define LOWER_RIGHT 4

class winTVMainWidget : public KTopLevelWidget
{
  Q_OBJECT

public:
  winTVMainWidget(int argc = 0, char **argv = NULL, QWidget* parent = NULL,
		  const char* name = NULL, rcfile *_rc=NULL );
  ~winTVMainWidget();

  winTVScreenWidget *winTVScreenPtr() { return winTVScreen; }
  QPopupMenu *getAudioMenu() { return smenu; }
  QPopupMenu *getChannelMenu() { return chmenu; }
    
  void emitSetupSignals();

public slots:
  // audio & volume
  void audioModeChangedSLOT(int mode);
  void volumeUpSLOT();
  void volumeDownSLOT();
  void volumeSLOT(int vl, int vr);
  void splitSlidersExtSLOT();

  // channel selection
  void channelUpSLOT();
  void channelDownSLOT();
  void channelChangedSLOT();

  // channel managing
  void addChannelSLOT();
  void editChannelSLOT();
  void deleteChannelSLOT();
  void copyChannelSLOT();
  void pasteChannelSLOT();

  // video clip
  void startVClipSLOT(struct MOVIE_PARAMS *);
  void endVClipSLOT();
  void frameVClipSLOT(int);
  void framelostVClipSLOT(int);
  void statVideoClipFrameSLOT(double);

protected slots:
  // buttonbar buttons and keys 
  void buttonsSLOT(int b);
  void keyPressedSLOT(int key);
  void userKeysConfigSLOT();
  void ircCodesConfigSLOT();

  // channel 
  void switchToChannelSLOT( int );
  void displaySpecialKeySLOT( KCodeEntry::codeType );

  // menu bar
  void setupSLOT();
  void naSLOT();
  void videoClipSLOT();
  void propertiesSLOT();
  void captureToggleSLOT();
  void screenShotSLOT();

  // audio: volume, mute, audio
  void soundSLOT();
  void audioAutoSLOT();
  void audioMonoSLOT();
  void audioStereoSLOT();
  void audioL1SLOT();
  void audioL2SLOT();
  void splitSlidersSLOT();

  // adjustments: aspect ratio and full screen 
  void adjustAspectRatioSLOT();
  void fullScreenSLOT();
  void fullSizeSLOT();

  // translation
  //void translateChannelSLOT(int channel);
  
  // channel file actions 
  void scanChannelsSLOT();
  void readyScanChannelsSLOT(int);
  void newChannelsSLOT();
  void saveChannelsSLOT();
  void saveChannelsAsSLOT();
  void loadChannelsSLOT();
  void importXAWTVChannelsSLOT();
  void importXTVSCREENChannelsSLOT();

  // ctab
  void defaultTabSLOT();
  void applyTabSLOT();
  void cancelTabSLOT();

  // mtab
  void defaultMtabSLOT();
  void applyMtabSLOT();
  void cancelMtabSLOT();

  // rc
  void saveRCSLOT();

  // menubar, toolbar, mousecursor, statusbar
  void toggleToolBarSLOT();
  void toggleMenuBarSLOT();
  void toggleStatusBarSLOT();
  void mousecursorToggleSLOT();

  // info 
  void toggleChannelBoxSLOT();
  void toggleTVonlySLOT();

  void vtxSLOT();

  void dataReceivedSLOT(int data);

  bool x11Event( XEvent * );

signals:
  void captureToggleSIGNAL(int);
  void audioModeChangedSIGNAL(int);
  void audioMuteToggledSIGNAL();
  void volumeChangedSIGNAL(int,int);
  void channelChangedSIGNAL();
  void toggleSplitSlidersSIGNAL();
  void newChannelListSIGNAL(QList<channel> *clist);
  void toggleChannelBoxSIGNAL( QPoint * );
  void toggleVClipSIGNAL();
  void frameVClipSIGNAL(int);
  void framelostVClipSIGNAL(int);
  void statVideoClipFrameSIGNAL(double);
  void x11EventSIGNAL( XEvent * );
  
protected slots:
  void closeEvent ( QCloseEvent *);
  void keyPressEvent ( QKeyEvent * );
  void resizeEvent( QResizeEvent * );
  void moveEvent( QMoveEvent * );
  void updateRects();

  void saveProperties (KConfig*);
  void readProperties (KConfig*);

private:
  void saveChannels(const char *FILE);
  void loadChannels(const char *FILE, bool import= false);

private:
  static QList<winTVMainWidget> windowList;

  winTVScreenWidget *winTVScreen;
  rcfile *rc;
  mixer *mix;

  // the toolbars
  KToolBar* toolbar;
  KMenuBar* menubar;
  KStatusBar* statusbar;
  QLCDNumber* lcd;
  QSlider* volslider;
  //QFrame *lcdframe;

  QPixmap  pm;
  QPixmap  ch_up_xpm, ch_down_xpm, uncapture_xpm, snap_xpm, aspect_xpm;
  QPixmap  fullsize_xpm, vol_up_xpm, mute_xpm, vol_down_xpm;
  QPixmap  capture_xpm, cs_xpm, exit_xpm;
       
  // keys & irc codes
  KKeyConfig *userKeys;
  KIRCWidget *ircCodes;

  // dialogs
  ctab *tab;
  cselector *selector;
  coptions *options;
  cfreq *freq;

  // option dialogs
  otab *mtab;
  omixdev *mixdev;
  oaspectratio *aspectratio;
  osnapshot *snapshot;
  ogeneral *general;
  ofullscreen *fullscreen;

  // cannel and country stuff
  QList<channel> channel_list;
  channel *lastCutCopy;
  bool copyChannel;

  winTVcsan *csan;

  // pop ups --> KPopupMenu  
  QPopupMenu *tvmenu,*smenu,*chmenu,*optmenu;
  int smid[10];
  int omid[10];
  int tvmid[10];

  // adjustments: aspect ratio and full screen 
  QRect oldPos;
  bool isfullscreen,isfullsize;

  // stuff
  char filename[255];
  char *cnamep;
  int capture;

  bool keyup;
  int key1;
  int key2;

  bool fixed;
  bool have_vm;
  bool wasEdit;
  bool res_was_switched;
};

#endif wintvmainincluded




